---
title: "博客使用说明"
date: 2025-03-09T01:07:23Z
tags: []
---

# 博客使用说明

这是一个基于 Astro + React 构建的个人博客系统，具有文章管理、项目展示、观影记录、读书记录等功能。本文将详细介绍如何使用和配置这个博客系统。

## 功能特点

1. **响应式设计**：完美适配桌面端和移动端
2. **深色模式**：支持自动和手动切换深色/浅色主题
3. **文章系统**：支持 Markdown 写作，带有标签和分类
4. **项目展示**：支持展示 GitHub、Gitea 和 Gitee 的项目
5. **观影记录**：集成豆瓣观影数据
6. **读书记录**：集成豆瓣读书数据
7. **旅行地图**：世界地图展示旅行足迹

## 基础配置

主要配置文件位于 `src/consts.ts`，你需要修改以下内容：

```typescript
// 网站基本信息
export const SITE_URL = 'https://your-domain.com';
export const SITE_NAME = "你的网站名称";

// 导航链接
export const NAV_LINKS = [
    { href: '/', text: '首页' },
    { href: '/articles', text: '文章' },
    // ... 可以根据需要修改
];

// 备案信息（如果需要）
export const ICP = '你的ICP备案号';
export const PSB_ICP = '你的公安备案号';
export const PSB_ICP_URL = '备案链接';

// 旅行足迹
export const VISITED_PLACES = ['你去过的地方'];

// 豆瓣ID
export const DOUBAN_ID = '你的豆瓣ID';

// Git平台配置
export const GIT_CONFIG = {
    github: {
        username: '你的GitHub用户名',
        token: '你的GitHub令牌'  // 可选
    },
    gitea: {
        url: '你的Gitea实例地址',
        username: '你的Gitea用户名',
        token: '你的Gitea令牌'  // 可选
    },
    gitee: {
        username: '你的Gitee用户名',
        token: '你的Gitee令牌'  // 可选
    }
};
```

## 文章写作

### 创建新文章

在 `src/content/articles` 目录下创建 `.md` 或 `.mdx` 文件。文章需要包含以下前置信息：

```markdown
---
title: "文章标题"
date: YYYY-MM-DD
tags: ["标签1", "标签2"]
---

文章内容...
```

### 文章列表展示

文章列表页面会自动获取所有文章并按日期排序展示，支持：
- 文章标题和摘要
- 发布日期
- 标签系统
- 阅读时间估算

## 项目展示

项目展示页面会自动从配置的 Git 平台获取你的项目信息，展示：
- 项目名称和描述
- Star 和 Fork 数
- 主要编程语言
- 最后更新时间

要启用项目展示，需要：
1. 在 `consts.ts` 中配置相应平台的用户名
2. 如果需要访问私有仓库，配置相应的访问令牌

## 观影和读书记录

系统会自动从豆瓣获取你的观影和读书记录，展示：
- 电影/书籍封面
- 标题
- 评分
- 观看/阅读日期

要启用此功能，需要：
1. 在 `consts.ts` 中配置你的豆瓣 ID
2. 确保你的豆瓣观影/读书记录是公开的

## 旅行地图

世界地图会根据 `VISITED_PLACES` 配置自动标记你去过的地方。支持：
- 中国省份级别的标记
- 世界国家级别的标记
- 交互式缩放和平移
- 鼠标悬停显示地名

## 主题切换

系统支持三种主题模式：
1. 跟随系统
2. 手动切换浅色模式
3. 手动切换深色模式

主题设置会被保存在浏览器的 localStorage 中。

## 性能优化

本博客系统采用了多项性能优化措施：
1. 静态页面生成
2. 图片懒加载
3. 代码分割
4. 样式按需加载
5. 响应式图片

## 部署说明

1. 构建项目：
```bash
npm run build
```

2. 构建产物位于 `dist` 目录

3. 将 `dist` 目录部署到你的服务器或静态托管平台

## 常见问题

1. **图片无法显示**
   - 检查图片路径是否正确
   - 确保图片已放入 `public` 目录

2. **豆瓣数据无法获取**
   - 确认豆瓣 ID 配置正确
   - 检查豆瓣记录是否公开

3. **Git 项目无法显示**
   - 验证用户名配置
   - 检查访问令牌是否有效
   - 确认 API 访问限制

## 更新日志

### 2024-03-21
- 初始版本发布
- 支持基本的博客功能
- 集成豆瓣数据展示
- 添加旅行地图功能

## 后续计划

1. 添加评论系统
2. 优化移动端体验
3. 增加更多自定义主题选项
4. 添加文章搜索功能
5. 支持更多外部服务集成

## 贡献指南

欢迎提交 Issue 和 Pull Request 来改进这个博客系统。在提交之前，请确保：

1. 代码符合项目的代码风格
2. 新功能有适当的测试覆盖
3. 文档已经更新

## 许可证

本项目采用 MIT 许可证。 